@@ -11,6 +11,8 @@ from bergen.utils import *
 
 
 class Actor:
+    expandInputs = True
+    shrinkOutputs = True
 
     def __init__(self, connector: Connector, queue:asyncio.Queue = None, loop=None) -> None:
         self.queue = queue or asyncio.Queue()
@@ -29,6 +31,9 @@ class Actor:
         self.template = None
         pass
 
+    async def log(self, message, level="INFO"):
+        console.log(f"[red] Actor: {message}")
+
 
 
     async def on_provide(self, provide: ProvideHandler):
@@ -110,16 +115,32 @@ class Actor:
 
                     elif isinstance(message, BouncedUnassignMessage):
                         if message.data.assignation in self.assignments: 
-                            await self.actor_progress(f"Cancellation of assignment {message.data.assignation}", level=DebugLevel.INFO)
+                            await self.log(f"Cancellation of assignment {message.data.assignation}", level=DebugLevel.INFO)
                             task = self.assignments[message.data.assignation]
                             if not task.done():
                                 task.cancel()
-                                await self.helper.pass_cancelled_done(message)
-
-                                await self.actor_progress(f"Cancellation of assignment suceeded", level=DebugLevel.INFO)
+                                unassign_done = UnassignDoneMessage(data={
+                                    "assignation": message.data.assignation
+                                },
+                                    meta = {
+                                        "reference": message.meta.reference,
+                                        "extensions": message.meta.extensions
+                                    }
+                                )
+                                await self.connector.forward(unassign_done)
+                                await self.log(f"Cancellation of assignment suceeded", level=DebugLevel.INFO)
                             else:
-                                await self.helper.pass_cancelled_failed(message, "Task was already Done")
-                                await self.actor_progress(f"Cancellation of assignment failed. Task was already Done", level=DebugLevel.INFO)
+                                unassign_critical = UnassignCriticalMessage(data={
+                                    "message": "Task was already done",
+                                    "type": "Exception"
+                                },
+                                    meta = {
+                                        "reference": message.meta.reference,
+                                        "extensions": message.meta.extensions
+                                    }
+                                )
+                                await self.connector.forward(unassign_critical)
+                                await self.log(f"Cancellation of assignment failed. Task was already Done", level=DebugLevel.INFO)
                                 #TODO: Maybe send this to arkitekt as well?
                         else:
                             raise Exception("Assignment never was at this pod. something went wrong")
@@ -132,6 +153,7 @@ class Actor:
 
             except asyncio.CancelledError:
                 await self.on_unprovide(None)
+                await self.log("Actor was beeing cancelled")
                 raise
 
         except Exception as e:
@@ -154,7 +176,7 @@ class Actor:
 
         await assign_handler.log(f"Assignment received", level=DebugLevel.INFO)
         try:
-            args, kwargs = await expandInputs(node=self.template.node, args=assign.data.args, kwargs=assign.data.kwargs)
+            args, kwargs = await expandInputs(node=self.template.node, args=assign.data.args, kwargs=assign.data.kwargs) if self.expandInputs else assign.data.args, assign.data.kwargs
             try:
                 await self._assign(assign_handler, reserve_handler, args, kwargs) # We dont do all of the handling here, as we really want to have a generic class for Generators and Normal Functions
             
@@ -165,7 +187,8 @@ class Actor:
                 raise
 
         except asyncio.CancelledError as e:
-            await reserve_handler.log(f"Cancellation of Assignment suceeded", level=DebugLevel.INFO)
+            await assign_handler.log(f"Cancellation of Assignment suceeded", level=DebugLevel.INFO)
+            await assign_handler.pass_cancelled()
             raise e
     
     async def __aenter__(self):
