@@ -28,7 +28,7 @@ class FunctionalFuncActor(FunctionalActor):
         result = await self.assign(*args, **kwargs)
 
         try:
-            shrinked_returns = await shrinkOutputs(self.template.node, result)
+            shrinked_returns = await shrinkOutputs(self.template.node, result) if self.shrinkOutputs else result
             await assign_handler.pass_result(shrinked_returns)
         except Exception as e:
             await assign_handler.pass_exception(e)
@@ -49,7 +49,7 @@ class FunctionalGenActor(FunctionalActor):
         provide_handler_context.set(self.provide_handler)
 
         async for result in self.assign(*args, **kwargs):
-            lastresult = await shrinkOutputs(self.template.node, result)
+            lastresult = await shrinkOutputs(self.template.node, result) if self.shrinkOutputs else result
             await assign_handler.pass_yield(lastresult)
 
         await assign_handler.pass_done()
