@@ -5,7 +5,7 @@ from enum import Enum
 class GrantType(str, Enum):
     IMPLICIT = "implicit"
     PASSWORD = "password"
-    BACKEND = "backend"
+    BACKEND = "client-credentials"
 
 class HerreConfig(BaseModel):
     secure: bool 
