@@ -7,14 +7,15 @@ from bergen.clients.default import Bergen
 
 class PointBergen(Bergen):
 
-    def __init__(self, *args, point_inward=None, point_outward=None, point_port=8000, point_type = DataPointType.GRAPHQL, scopes= [],**kwargs) -> None:
+    def __init__(self, *args, point_inward=None, point_outward=None, point_port=8000, point_type = DataPointType.GRAPHQL, scopes= [], needs_negotiation=False, **kwargs) -> None:
         super().__init__(*args, client_type = ClientType.POINT, scopes=scopes + ["host","provide"], **kwargs)
         self.model_registry: Dict[str, DataModel] = {}
         self.negotiate_additionals = {
             "inward": point_inward,
             "outward": point_outward,
             "port": point_port,
-            "pointType": point_type.value
+            "pointType": point_type.value,
+            "needsNegotiation": needs_negotiation,
         }
 
 
