@@ -39,7 +39,7 @@ class Reservation:
             self.on_progress = lambda message, level: self.log(f"[magenta]{level}", message) if self.monitor.progress else None
         else:
             self.log = lambda level, message: logger.info(message)
-            self.on_progress = False
+            self.on_progress = None
 
 
         self.loop = loop or asyncio.get_event_loop()
@@ -106,7 +106,7 @@ class Reservation:
                     yield outs
 
                 if isinstance(message, AssignProgressMessage):
-                    self.on_progress(message.data.message, message.data.level)
+                    if self.on_progress: self.on_progress(message.data.message, message.data.level)
                 
                 if isinstance(message, AssignCriticalMessage):
                     raise AssignmentException(message.data.type + message.data.message)
