@@ -90,8 +90,11 @@ class BasePostman(Hookable):
                     function(f"[red]Race Condition! Assignation Return before being Cancelled on the Server. Omitting Result!", level=ProgressLevel.DEBUG)
 
         elif isinstance(message, AssignProgressMessage):
-            function = self.assignment_progress_functions[reference]
-            function(message.data.message, level=message.data.level)
+            if reference in self.assignment_progress_functions:
+                function = self.assignment_progress_functions[reference]
+                function(message.data.message, level=message.data.level)
+            else:
+                logger.warning(f"Received unwanted Progress {message}")
 
         elif isinstance(message, AssignCriticalMessage):
             future = self.assignments.pop(reference)
@@ -104,8 +107,11 @@ class BasePostman(Hookable):
             future.set_result(message)
 
         elif isinstance(message, UnassignProgressMessage):
-            function = self.unassignment_progress_functions[reference]
-            function(message.data.message, level=message.data.level)
+            if reference in self.unassignment_progress_functions:
+                function = self.unassignment_progress_functions[reference]
+                function(message.data.message, level=message.data.level)
+            else:
+                logger.warning(f"Received unwanted Progress {message}")
 
         elif isinstance(message, UnassignCriticalMessage):
             future = self.unassignments.pop(reference)
@@ -118,8 +124,11 @@ class BasePostman(Hookable):
             future.set_result(message)
 
         elif isinstance(message, ReserveProgressMessage):
-            function = self.reservations_progress_functions[reference]
-            function(message.data.message, level=message.data.level)
+            if reference in self.reservations_progress_functions:
+                function = self.reservations_progress_functions[reference]
+                function(message.data.message, level=message.data.level)
+            else:
+                logger.warning(f"Received unwanted Progress {message}")
 
         elif isinstance(message, ReserveCriticalMessage):
             future = self.reservations.pop(reference)
@@ -132,8 +141,12 @@ class BasePostman(Hookable):
             future.set_result(message)
 
         elif isinstance(message, UnreserveProgressMessage):
-            function = self.unreservations_progress_functions[reference]
-            function(message.data.message, level=message.data.level)
+            if reference in self.unreservations_progress_functions:
+                function = self.unreservations_progress_functions[reference]
+                function(message.data.message, level=message.data.level)
+            else:
+                logger.warning(f"Received unwanted Progress {message}")
+
 
         elif isinstance(message, UnreserveCriticalMessage):
             future = self.unreservations.pop(reference)
