@@ -59,7 +59,7 @@ class BaseProvider(Hookable):
         self.auto_provided_templates = [] # Templates that this provide will try to provide on startup
 
 
-    def template(self, node: Node, policy: PodPolicy = MultiplePodPolicy(), auto_provide=False, on_provide=None,  on_unprovide=None, **implementation_details):
+    def template(self, node: Node, policy: PodPolicy = MultiplePodPolicy(), auto_provide=False, on_provide=None,  on_unprovide=None, bypass_shrink=False, bypass_expand=False, **implementation_details):
 
         def real_decorator(function_or_actor):
             assert callable(function_or_actor) or issubclass(function_or_actor, Actor), "Please only decorate functions or subclasses of Actor"
@@ -79,12 +79,15 @@ class BaseProvider(Hookable):
                 is_asyncgen = inspect.isasyncgenfunction(function_or_actor)
                 is_function = inspect.isfunction(function_or_actor)
 
+                class_attributes = {"assign": staticmethod(function_or_actor), "expandInputs": not bypass_expand, "shrinkOutputs":  not bypass_shrink}
+
+
                 if is_coroutine:
-                    actorClass =  type(f"GeneratedActor{template.id}",(FunctionalFuncActor,), {"assign": staticmethod(function_or_actor)})
+                    actorClass =  type(f"GeneratedActor{template.id}",(FunctionalFuncActor,), class_attributes)
                 elif is_asyncgen:
-                    actorClass =  type(f"GeneratedActor{template.id}",(FunctionalGenActor,), {"assign": staticmethod(function_or_actor)})
+                    actorClass =  type(f"GeneratedActor{template.id}",(FunctionalGenActor,), class_attributes)
                 elif is_function:
-                    actorClass = type(f"GeneratedActor{template.id}",(FunctionalThreadedFuncActor,), {"assign": staticmethod(function_or_actor)})
+                    actorClass = type(f"GeneratedActor{template.id}",(FunctionalThreadedFuncActor,), class_attributes)
                 else:
                     raise Exception(f"Unknown type of function {function_or_actor}")
             
@@ -166,7 +169,8 @@ class BaseProvider(Hookable):
         except Exception as e:
             logger.error(e)
             critical_error = ProvideCriticalMessage(data={
-            "message": str(e)
+            "message": str(e),
+            "type": e.__class__.__name__
             }, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
             await self.forward(critical_error)
             raise e
