@@ -1,6 +1,8 @@
 
 
 from abc import ABC, abstractmethod
+
+from websockets.exceptions import ConnectionClosedError
 from bergen.messages import *
 from bergen.messages.utils import expandToMessage
 from bergen.messages.base import MessageModel
@@ -36,7 +38,7 @@ class WebsocketProvider(BaseProvider):
 
         self.pending = None
 
-        self.auto_reconnect= auto_reconnect
+        self.auto_reconnect = True
         self.allowed_retries = 2
         self.current_retries = 0
 
@@ -44,12 +46,19 @@ class WebsocketProvider(BaseProvider):
     async def connect(self):
         self.incoming_queue = asyncio.Queue()
         self.outgoing_queue = asyncio.Queue()
+
+
         self.tasks = {}
 
         self.startup_task = create_task(self.startup())
 
 
     async def disconnect(self) -> str:
+
+        for task in self.pending:
+            task.cancel()
+
+
         if self.connection: await self.connection.close()
 
         if self.pending:
@@ -69,16 +78,18 @@ class WebsocketProvider(BaseProvider):
             await self.connect_websocket()
         except Exception as e:
 
-            logger.error(f"Peasent Connection failed {e}")
+            console.print("[blue] Connection attempt as Provider failed")
             self.current_retries += 1
-            if self.current_retries < self.allowed_retries and self.auto_reconnect:
+            if self.auto_reconnect:
                 sleeping_time = (self.current_retries + 1)
-                logger.info(f"Retrying in {sleeping_time} seconds")
+                console.print(f"[blue] Trying to Reconnect as Provider in {sleeping_time} seconds")
                 await asyncio.sleep(sleeping_time)
                 await self.startup()
             else:
-                logger.error("No reconnecting attempt envisioned. Shutting Down!")
-                return
+                console.print("[blue]Provider: No reconnecting attempt envisioned. Shutting Down!")
+                console.print_exception()
+
+        console.print("[blue] Sucessfully Established A Connection to Provider Endpoint")
 
         self.consumer_task = create_task(
             self.consumer()
@@ -97,18 +108,26 @@ class WebsocketProvider(BaseProvider):
             return_when=asyncio.FIRST_EXCEPTION
         )
 
-        if DEBUG: 
+        try:
             for task in done:
                 if task.exception():
                     raise task.exception()
+        except ConnectionClosedError:
+            console.print("[blue] Provider Connection was closed. Trying Reconnect")
+        except:
+            console.print_exception()
                     
         logger.error(f"Provider: Lost connection inbetween everything :( {[ task.exception() for task in done]}")
         logger.error(f'Provider: Reconnecting')
 
+        
+
+        if self.connection: await self.connection.close()
+
         for task in self.pending:
             task.cancel()
 
-        if self.connection: await self.connection.close()
+        console.log("Trying to Reconnect")
         self.current_retries = 0 # reset retries after one successfull connection
         await self.startup() # Attempt to ronnect again
         
@@ -116,10 +135,10 @@ class WebsocketProvider(BaseProvider):
     async def connect_websocket(self):
         uri = f"{self.websocket_protocol}://{self.websocket_host}:{self.websocket_port}/provider/?token={self.token}"
         self.connection = await websockets.client.connect(uri)
+        logger.info("Sueccess fully connected Provider ")
 
 
     async def consumer(self):
-        logger.warning(" [x] Awaiting Provision Calls")
         async for message in self.connection:
             await self.incoming_queue.put(message)
 
@@ -128,6 +147,8 @@ class WebsocketProvider(BaseProvider):
             message = await self.outgoing_queue.get()
             await self.connection.send(message.to_channels())
 
+            self.outgoing_queue.task_done()
+
     async def forward(self, message: MessageModel) -> str:
         logger.info(f"Sending {message}")
         await self.outgoing_queue.put(message)
@@ -135,9 +156,13 @@ class WebsocketProvider(BaseProvider):
     async def workers(self):
         while True:
             message_str = await self.incoming_queue.get()
-            message = expandToMessage(json.loads(message_str))
-            logger.info("Message")
-            await self.on_message(message)
+            try:
+                message = expandToMessage(json.loads(message_str))
+                await self.on_message(message)
+            except:
+                raise
+
+
             self.incoming_queue.task_done()
     
 
