@@ -11,6 +11,7 @@ NEGOTIATION_GQL = TypedGQL("""
       $port: Int,
       $version: String,
       $pointType: DataPointTypeInput,
+      $needsNegotiation: Boolean
       
       ) {
   negotiate(
@@ -19,18 +20,21 @@ NEGOTIATION_GQL = TypedGQL("""
       outward: $outward,
       port: $port,
       version: $version,
-      pointType: $pointType
-  
+      pointType: $pointType,
+      needsNegotiation: $needsNegotiation
   ) {
     timestamp
-    extensions
     models {
         identifier
         point {
+            app {
+                name
+            }
             id
             outward
             port
             type
+            needsNegotiation
         }
     }
     postman {
