@@ -32,7 +32,7 @@ class DataPointRegistry(object):
     def createWardForDatapoint(self, point, bergen) -> BaseWard:
 
         if point.app.name == bergen.application.name:
-            print("Will not create Ward for same applicaiton")
+            console.log("[red] Datapoint App is the Same as this One, will not create own Ward!!!")
             return None
 
         if point.id in self.pointIDWardMap:
